@@ -54,6 +54,7 @@ package com.openexchange.custom.parallels.impl;
 import java.io.IOException;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
+import java.text.MessageFormat;
 import java.util.Arrays;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -61,6 +62,7 @@ import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.osgi.framework.ServiceException;
+import org.slf4j.Logger;
 import com.openexchange.ajax.PermissionServlet;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.writer.ResponseWriter;
@@ -75,27 +77,23 @@ import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
 
 /**
- * 
+ *
  * Servlet which returns needed Data for the Parallels direct links manipulation
  * and also returns some data like username,password etc.
- * 
+ *
  * Also does jobs for the other GUI Plugins
- * 
+ *
  * @author <a href="mailto:manuel.kraft@open-xchange.com">Manuel Kraft</a>
- * 
+ *
  */
 public final class ParallelsInfoServlet extends PermissionServlet {
 
-
-
     /**
-     * 
+     *
      */
     private static final long serialVersionUID = -6454818806420432111L;
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.loggerFor(ParallelsInfoServlet.class);
-
-
+    private static final Logger LOG = org.slf4j.LoggerFactory.getLogger(ParallelsInfoServlet.class);
 
     /**
      * Initializes
@@ -124,19 +122,19 @@ public final class ParallelsInfoServlet extends PermissionServlet {
 
     /**
      * Performs the GET request!
-     * 
+     *
      * This will return a Json Object with username,password,context
      * name,context-id,branding-url. Can then be used in IFRAME Plugins and
      * for manipulating direct urls.
-     * 
+     *
      * obj.put("login"
 		obj.put("password",
 		obj.put("context_id"
 		obj.put("context_name"
 		obj.put("mail"
 		obj.put("branding_host"
-     * 
-     * 
+     *
+     *
      * @param req
      *            The servlet request
      * @param resp
@@ -174,9 +172,9 @@ public final class ParallelsInfoServlet extends PermissionServlet {
 
             mail = userobject.getMail();
         } catch (final OXException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final ServiceException e) {
-            LOG.error("Error resolving branded url for context "+contextid);
+            LOG.error("Error resolving branded url for context {}", contextid);
         }
 
         final JSONObject obj = new JSONObject();
@@ -215,29 +213,24 @@ public final class ParallelsInfoServlet extends PermissionServlet {
 
         // load suffix for branding string dynamically in loginmappings
         final String suffix_branded = configservice.getProperty(ParallelsOptions.PROPERTY_BRANDING_SUFFIX);
-        // for debugging purposes
-        if(LOG.isDebugEnabled()){
-            LOG.debug("Loaded loginmappings "+Arrays.toString(login_mappings)+" for context "+ctx.getContextId());
-        }
+        LOG.debug("Loaded loginmappings {} for context {}", Arrays.toString(login_mappings), ctx.getContextId());
         boolean found_host = false;
         if( null != suffix_branded && suffix_branded.length() != 0) {
             for (final String login_mapping : login_mappings) {
                 if(login_mapping.startsWith(suffix_branded)){
                     /**
-                     * 
+                     *
                      *  We found our mapping which contains the branded host!
-                     * 
+                     *
                      *  Now split up the string to get the host part
-                     * 
+                     *
                      */
                     final String[] URL_ = login_mapping.split("\\|\\|"); // perhaps replace with substring(start,end) if would be faster
                     if(URL_.length!=3){
-                        LOG.error("getBrandingHostFromLoginMappings: Could not split up branded host "+login_mapping+" login mapping for context "+ctx.getContextId());
+                        LOG.error("getBrandingHostFromLoginMappings: Could not split up branded host {} login mapping for context {}", login_mapping, ctx.getContextId());
                     }else{
                         branded_host = URL_[2];
-                        if(LOG.isDebugEnabled()){
-                            LOG.debug("Successfully resolved HOST to "+branded_host+" for branded context "+ctx.getContextId());
-                        }
+                        LOG.debug("Successfully resolved HOST to {} for branded context {}", branded_host, ctx.getContextId());
                     }
                 }
             }
@@ -252,7 +245,7 @@ public final class ParallelsInfoServlet extends PermissionServlet {
                 } catch (UnknownHostException e) { }
             }
             if( null == branded_host || branded_host.length() == 0 ) {
-                LOG.warn("getHostname: Unable to determine any hostname for context "+ctx.getContextId());
+                LOG.warn("getHostname: Unable to determine any hostname for context {}", ctx.getContextId());
             }
         }
 
